Crate replicante_util_actixweb
source · [−]Structs
On-demand Actix Web App configuration with functions and closures.
Configuration context provided by AppConfig to callbacks.
Error information returned by functions in case of errors.
Actix Web middleware to log requests.
Set of metrics tracked by the MetricsMiddleware for actix web.
ActixWeb Responder to export prometheus metrics.
Actix Web middleware to capture request metrics.
Actix Web middleware to integrate with sentry.
Actix Web middleware to inject an opentracingrust::Span on each request.
Enums
Exhaustive list of possible errors emitted by this crate.
Traits
Sentry Hub extension with actix-web methods.
Interface for types that describe endpoint roots.
Functions
request_spanDeprecated
Access the request’s tracing span.
Access the request’s tracing span.